package com.diagbot.client;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.diagbot.client.hystrix.MedAppealExamineInfoServiceHystrix;
import com.diagbot.dto.*;
import com.diagbot.vo.*;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;



/**
 * @description: 申诉功能远程调用
 * @author: zhoutg
 * @date: 2020/4/13 18:28
 */
@FeignClient(name = "gateway-service", url = "${appeal.address}", fallback = MedAppealExamineInfoServiceHystrix.class)
public interface MedAppealExamineInfoServiceClient {
    /**
     * 获取申诉记录
     * @param getComplaintRecordVO
     * @return
     */
    @PostMapping(value = "/report-service/medAppealExamineInInfoManage/getComplaintRecord")
    RespDTO<Page<GetComplaintRecordDTO>> getComplaintRecord(@RequestBody GetComplaintRecordVO getComplaintRecordVO);

    /**
     * 获取申诉审核列表
     * @param getAppealReviewVO
     * @return
     */
    @PostMapping(value = "/report-service/medAppealExamineInInfoManage/getAppealReview")
    RespDTO<Page<GetAppealReviewDTO>> getAppealReview(@RequestBody GetAppealReviewVO getAppealReviewVO);

    /**
     *审核获取申述详情
     * @param getAuditVO
     * @return
     */
    @PostMapping(value = "/report-service/medAppealExamineInInfoManage/getAudit")
    RespDTO<GetAuditDTO> getAudit(@RequestBody GetAuditVO getAuditVO);

    /**
     *审核通过
     * @param approvedVo
     * @return
     */
    @PostMapping(value = "/report-service/medAppealExamineInInfoManage/approved")
    RespDTO<Boolean> approved(@RequestBody ApprovedVo approvedVo);

    /**
     *驳回
     * @param rejectedVo
     * @return
     */
    @PostMapping(value = "/report-service/medAppealExamineInInfoManage/rejected")
    RespDTO<Boolean> rejected(@RequestBody RejectedVo rejectedVo);

    /**
     *审核查看
     * @param getApprovedViewVO
     * @return
     */
    @PostMapping(value = "/report-service/medAppealExamineInInfoManage/getApprovedView")
    RespDTO<GetAppealInfoDTO> getApprovedView(@RequestBody GetApprovedViewVO getApprovedViewVO);

    /**
     *待审核数量
     * @param getAuditNumberVO
     * @return
     */
    @PostMapping(value = "/report-service/medAppealExamineInInfoManage/getAuditNumber")
    RespDTO<Integer> getAuditNumber(@RequestBody GetAuditNumberVO getAuditNumberVO);


}



