package com.diagbot.web;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.diagbot.annotation.SysLogger;
import com.diagbot.client.MedAppealExamineInfoServiceClient;
import com.diagbot.dto.*;
import com.diagbot.facade.MedAppealExamineInfoManagementFacade;
import com.diagbot.facade.SysDictionaryFacade;
import com.diagbot.facade.SysHospitalSetFacade;
import com.diagbot.util.StringUtil;
import com.diagbot.util.SysUserUtils;
import com.diagbot.vo.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.Map;


/**
 * <p>
 * 申诉审核 前端控制器
 * </p>
 *
 * @author wangfeng
 * @since 2020-07-06
 */
@RestController
@RequestMapping("/qc/appealExamineInfo")
@Api(value = "申诉审核API", tags = { "申诉审核API" })
@SuppressWarnings("unchecked")
public class MedAppealExamineInfoController {
    @Autowired
    MedAppealExamineInfoServiceClient medAppealExamineInfoServiceClient;
    @Autowired
    SysDictionaryFacade sysDictionaryFacade;
    @Autowired
    MedAppealExamineInfoManagementFacade medAppealExamineInfoManagementFacade;
    @Autowired
    SysHospitalSetFacade sysHospitalSetFacade;

    @ApiOperation(value = "获取申述记录列表[by:zhanghang]",
            notes = "获取申诉任务接口")
    @PostMapping("/getComplaintRecord")
    @SysLogger("getComplaintRecord")
    public RespDTO<GetComplaintRecordDTO> getComplaintRecord(@RequestBody GetComplaintRecordVO getComplaintRecordVO) {
        String userId = SysUserUtils.getCurrentPrincipleID();
        String hospitalId = SysUserUtils.getCurrentHospitalID();
        getComplaintRecordVO.setHospitalId(Long.valueOf(hospitalId));
        getComplaintRecordVO.setComplaintId(Long.valueOf(userId));
        RespDTO<Page<GetComplaintRecordDTO>> complaintRecord = medAppealExamineInfoServiceClient.getComplaintRecord(getComplaintRecordVO);
        return RespDTO.onSuc(complaintRecord);
    }

    @ApiOperation(value = "获取申诉审核列表[by:zhanghang]",
            notes = "获取申诉审核列表")
    @PostMapping("/getAppealReview")
    public RespDTO<GetAppealReviewDTO> getAppealReview(@RequestBody GetAppealReviewVO getAppealReviewVO) {
        String userId = SysUserUtils.getCurrentPrincipleID();
        String hospitalId = SysUserUtils.getCurrentHospitalID();
        getAppealReviewVO.setHospitalId(Long.valueOf(hospitalId));
        getAppealReviewVO.setAppealId(Long.valueOf(userId));
        RespDTO<Page<GetAppealReviewDTO>> appealReview = medAppealExamineInfoServiceClient.getAppealReview(getAppealReviewVO);
        return RespDTO.onSuc(appealReview);
    }

    @ApiOperation(value = "审核获取申述详情[by:zhanghang]",
            notes = "审核获取申述详情")
    @PostMapping("/getAudit")
    public RespDTO<GetAuditDTO> getAudit(@RequestBody GetAuditVO getAuditVO) {
        RespDTO<GetAuditDTO> audit = medAppealExamineInfoServiceClient.getAudit(getAuditVO);
        return RespDTO.onSuc(audit);
    }

    @ApiOperation(value = "审核通过[by:zhanghang]",
            notes = "审核通过")
    @PostMapping("/approved")
    @Transactional
    public RespDTO<Boolean> approved(@RequestBody ApprovedVo approvedVo) {
        String userId = SysUserUtils.getCurrentPrincipleID();
        String hospitalId = SysUserUtils.getCurrentHospitalID();
        approvedVo.setHospitalId(Long.valueOf(hospitalId));
        approvedVo.setAppealId(Long.valueOf(userId));

        //获取操作流节点
        String mapping = sysHospitalSetFacade.getValue(Long.parseLong(SysUserUtils.getCurrentHospitalID()),"work_flow_node_mapping");
        if(StringUtil.isNotEmpty(mapping)){
            JSONObject mapJSON = JSONObject.parseObject(mapping);
            approvedVo.setWorkFlowNodeId(mapJSON.getLong("approved"));
        }
        // return RespDTO.onSuc(medAppealExamineInfoServiceClient.approved(approvedVo));
        return RespDTO.onSuc(medAppealExamineInfoManagementFacade.approved(approvedVo));
    }

    @ApiOperation(value = "驳回[by:zhanghang]",
            notes = "驳回")
    @PostMapping("/rejected")
    @Transactional
    public RespDTO<Boolean> rejected(@RequestBody RejectedVo rejectedVo) {
        String userId = SysUserUtils.getCurrentPrincipleID();
        String hospitalId = SysUserUtils.getCurrentHospitalID();
        rejectedVo.setHospitalId(Long.valueOf(hospitalId));
        rejectedVo.setAppealId(Long.valueOf(userId));
        //获取操作流节点
        String mapping = sysHospitalSetFacade.getValue(Long.parseLong(SysUserUtils.getCurrentHospitalID()),"work_flow_node_mapping");
        if(StringUtil.isNotEmpty(mapping)){
            JSONObject mapJSON = JSONObject.parseObject(mapping);
            rejectedVo.setWorkFlowNodeId(mapJSON.getLong("rejected"));
        }
        return RespDTO.onSuc(medAppealExamineInfoServiceClient.rejected(rejectedVo));
    }
    @ApiOperation(value = "审核查看[by:zhanghang]",
            notes = "审核查看")
    @PostMapping("/getApprovedView")
    public RespDTO<GetAppealInfoDTO> getApprovedView(@RequestBody GetApprovedViewVO getApprovedViewVO) {

        return RespDTO.onSuc(medAppealExamineInfoServiceClient.getApprovedView(getApprovedViewVO));
    }

    @ApiOperation(value = "获取操作类型及状态[by:zhanghang]",
            notes = "获取操作类型及状态")
    @PostMapping("/getAppealReviewDictionary")
    public RespDTO<Map<String,Map<String,String>>> getAppealReviewDictionary() {
        Map<String, String> appealOperationDictionary = sysDictionaryFacade.getAppealOperationDictionary();
        Map<String, String> appealStatusDictionary = sysDictionaryFacade.getAppealStatusDictionary();
        Map<String, Map<String, String>> appealReviewMap = new HashMap<>();
        if(appealOperationDictionary!=null && appealStatusDictionary!=null){
            appealReviewMap.put("操作类型",appealOperationDictionary);
            appealReviewMap.put("状态",appealStatusDictionary);
        }
        return RespDTO.onSuc(appealReviewMap);
    }

    @ApiOperation(value = "获取待审核数量[by:zhanghang]",
            notes = "获取待审核数量")
    @PostMapping("/getAuditNumber")
    public RespDTO<Integer> getAuditNumber(@RequestBody GetAuditNumberVO getAuditNumberVO) {
        String userId = SysUserUtils.getCurrentPrincipleID();
        getAuditNumberVO.setId(Long.valueOf(userId));
        return RespDTO.onSuc(medAppealExamineInfoServiceClient.getAuditNumber(getAuditNumberVO));
    }
}
